@@ -73,6 +73,7 @@ from awscli.customizations.streamingoutputarg import add_streaming_output_arg
 from awscli.customizations.toplevelbool import register_bool_params
 from awscli.customizations.waiters import register_add_waiters
 from awscli.customizations.opsworkscm import register_alias_opsworks_cm
+from awscli.customizations.mturk import register_alias_mturk_command
 
 
 def awscli_initialize(event_handlers):
@@ -148,3 +149,4 @@ def awscli_initialize(event_handlers):
     register_ec2_page_size_injector(event_handlers)
     cloudformation_init(event_handlers)
     register_alias_opsworks_cm(event_handlers)
+    register_alias_mturk_command(event_handlers)
